pub struct DeviceCodePollResponse {
pub status: String,
pub token: Option<String>,
pub user_id: Option<String>,
pub device_id: Option<String>,
pub email: Option<String>,
pub identity_provider: Option<String>,
}Fields
status: Stringtoken: Option<String>user_id: Option<String>device_id: Option<String>email: Option<String>identity_provider: Option<String>Implementations
Sourceimpl DeviceCodePollResponse
impl DeviceCodePollResponse
Sourcepub fn token(&self) -> &str
pub fn token(&self) -> &str
Returns the value of token, or the default value if token is unset.
Sourcepub fn user_id(&self) -> &str
pub fn user_id(&self) -> &str
Returns the value of user_id, or the default value if user_id is unset.
Sourcepub fn device_id(&self) -> &str
pub fn device_id(&self) -> &str
Returns the value of device_id, or the default value if device_id is unset.
Sourcepub fn email(&self) -> &str
pub fn email(&self) -> &str
Returns the value of email, or the default value if email is unset.
Sourcepub fn identity_provider(&self) -> &str
pub fn identity_provider(&self) -> &str
Returns the value of identity_provider, or the default value if identity_provider is unset.