pub struct KeyBundlePutRequest {
pub device_id: String,
pub ephemeral_public_key: String,
pub encrypted_bundle: String,
}Fields
device_id: Stringephemeral_public_key: Stringencrypted_bundle: StringTrait Implementations
Sourceimpl Clone for KeyBundlePutRequest
impl Clone for KeyBundlePutRequest
Sourcefn clone(&self) -> KeyBundlePutRequest
fn clone(&self) -> KeyBundlePutRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KeyBundlePutRequest
impl Debug for KeyBundlePutRequest
Sourceimpl Default for KeyBundlePutRequest
impl Default for KeyBundlePutRequest
Sourceimpl<'de> Deserialize<'de> for KeyBundlePutRequestwhere
KeyBundlePutRequest: Default,
impl<'de> Deserialize<'de> for KeyBundlePutRequestwhere
KeyBundlePutRequest: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for KeyBundlePutRequest
impl Message for KeyBundlePutRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for KeyBundlePutRequest
impl PartialEq for KeyBundlePutRequest
Sourcefn eq(&self, other: &KeyBundlePutRequest) -> bool
fn eq(&self, other: &KeyBundlePutRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for KeyBundlePutRequest
impl Serialize for KeyBundlePutRequest
impl StructuralPartialEq for KeyBundlePutRequest